FastTextPrediction class

A single prediction result returned by FastTextModel.predict.

Constructors

FastTextPrediction({required String label, required double probability})
const

Properties

cleanLabel String
Returns the label with the default __label__ prefix removed.
no setter
hashCode int
The hash code for this object.
no setteroverride
label String
The raw label string as stored in the model, e.g. '__label__en'.
final
probability double
Prediction probability in the range 0.0, 1.0.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override